@@ -10,10 +10,11 @@ class SetTemplateCommentRequest(BaseModel):
     :type comment: str
     """
 
-    def __init__(self, comment: str):
+    def __init__(self, comment: str, **kwargs):
         """SetTemplateCommentRequest
 
         :param comment: Comment for the template
         :type comment: str
         """
         self.comment = comment
+        self._kwargs = kwargs
